@@ -18,7 +18,7 @@ use Time::Piece;
 use DBI;
 
 
-our $VERSION = '0.085';
+our $VERSION = '0.091';
 
 
 =head1 NAME
@@ -42,7 +42,8 @@ This Data class contains a story, as posted by the editors of a site.
 
 =head1 METHODS
 
-This class implements several methods, reimplements the load method, but inherits some from L<AxKit::App::TABOO::Data>.
+This class implements several methods, reimplements the load method,
+but inherits some from L<AxKit::App::TABOO::Data>.
 
 =over
 
@@ -60,7 +61,6 @@ AxKit::App::TABOO::Data::Story->elementneedsparse("minicontent, content");
 
 sub new {
     my $that  = shift;
-    my $username = shift;
     my $class = ref($that) || $that;
     my $self = {
 	storyname  => undef,
@@ -90,24 +90,36 @@ sub new {
     return $self;
 }
 
-#use Alias qw(attr);
-#our ($storyname, $sectionid, $image, $primcat, $seccat, $freesubject, $editorok, $title, $minicontent, $content, $username, $USER, $submitterid, $SUBMITTER, $linktext, $timestamp, $lasttimestamp, $ONFILE);
-
 
 =item C<load(what => fields, limit => {sectionid => value, storyname => value, [...]})>
 
-This class reimplements the load method, to support the fact that some data may be stored as arrays in the datastore. It shares the API of the parent class. It is useful to note, however, that there are two fields that you most likely would want to specify for the common use of retrieving a specific story:
+This class reimplements the load method, to support the fact that some
+data may be stored as arrays in the datastore. It shares the API of
+the parent class. It is useful to note, however, that there are two
+fields that you most likely would want to specify for the common use
+of retrieving a specific story:
 
 =over
 
 
-=item * The C<sectionid> which the story has been posted to. Typically, this string will be taken directly from the URI. The use of sections makes it possible to divide the site in different ways. As of 0.07, sections are a type of L<category|AxKit::App::TABOO::Data::Category>, specifically C<stsec>, but they are not intended to be like the C<categ> types. Rather, one can have sections with "small news", i.e. blatant rip-offs of other news sites with a few comments added, or longer articles with more unique content.
+=item * The C<sectionid> which the story has been posted
+to. Typically, this string will be taken directly from the URI. The
+use of sections makes it possible to divide the site in different
+ways. Sections are a type of
+L<category|AxKit::App::TABOO::Data::Category>, specifically C<stsec>,
+but they are not intended to be like the C<categ> types. Rather, one
+can have sections with "small news", i.e. blatant rip-offs of other
+news sites with a few comments added, or longer articles with more
+unique content.
 
-=item * C<storyname> is a unique identifier for the story. This too will typically be derived from the URI directly.
+=item * C<storyname> is a unique identifier for the story. This too
+will typically be derived from the URI directly.
 
 =back
 
-It is of course possible to identify a single story by a completely different set of parameters, and you can do that too, but it is not a very common thing to do. 
+It is of course possible to identify a single story by a completely
+different set of parameters, and you can do that too, but it is not a
+very common thing to do.
 
 
 =cut
@@ -131,8 +143,12 @@ sub load
 
 =item C<adduserinfo()>
 
-When data has been loaded into an object of this class, it will contain a string only identifying a user. 
-This method will replace those strings (for the user posting the article, and for the submitter who sent the article to the site) with a reference to a L<AxKit::App::TABOO::Data::User>-object, and that object's C<load_name> method will be called. After this has been done, the story will effectively have all the user information it needs. 
+When data has been loaded into an object of this class, it will
+contain a string only identifying a user.  This method will replace
+those strings (for the user posting the article, and for the submitter
+who sent the article to the site) with a reference to a
+L<AxKit::App::TABOO::Data::User>-object, containing the needed user
+information.
 
 =cut
 
@@ -151,7 +167,11 @@ sub adduserinfo {
 
 =item C<addcatinfo()>
 
-Similarly to adding user info, this method will also add category information, for different types of categories, again by creating a reference to a L<AxKit::App::TABOO::Data::Category>-object and calling its C<load>-method with the string from the data loaded by the story as argument. 
+Similarly to adding user info, this method will also add category
+information, for different types of categories, again by creating a
+reference to a L<AxKit::App::TABOO::Data::Category>-object and calling
+its C<load>-method with the string from the data loaded by the story
+as argument.
 
 =cut
 
@@ -187,9 +207,15 @@ sub addcatinfo {
 
 =item C<timestamp([($section, $storyname)])>
 
-The timestamp method will retrieve the timestamp of the story. If the timestamp has been loaded earlier from the data storage (for example by the load method), you need not supply any arguments. If the timestamp is not available, you must supply the section and storyname identifiers, the method will then load it into the data structure first. 
+The timestamp method will retrieve the timestamp of the story. If the
+timestamp has been loaded earlier from the data storage (for example
+by the load method), you need not supply any arguments. If the
+timestamp is not available, you must supply the section and storyname
+identifiers, the method will then load it into the data structure
+first.
 
-The timestamp method will return a Time::Piece object with the requested time information.
+The timestamp method will return a Time::Piece object with the
+requested time information.
 
 =cut
 
@@ -206,9 +232,12 @@ sub timestamp {
 
 =item C<lasttimestamp([($section, $storyname)])>
 
-This does exactly the same as the timestamp method, but instead returns the lasttimestamp, which is intended to show when anything connected to the story (which may include comments) last changed. 
+This does exactly the same as the timestamp method, but instead
+returns the lasttimestamp, which is intended to show when anything
+connected to the story (which may include comments) last changed.
 
-It may require arguments like the timestamp method does, and it will return a Time::Piece object.
+It may require arguments like the timestamp method does, and it will
+return a Time::Piece object.
 
 
 =cut
@@ -251,43 +280,69 @@ sub editorok {
 
 =head1 STORED DATA
 
-The data is stored in named fields, and for certain uses, it is good to know them. If you want to subclass this class, you might want to use the same names, see the documentation of L<AxKit::APP::TABOO::Data> for more about this. 
+The data is stored in named fields, and for certain uses, it is good
+to know them. If you want to subclass this class, you might want to
+use the same names, see the documentation of
+L<AxKit::APP::TABOO::Data> for more about this.
 
-In this class it gets even more interesting, because you may pass a list of those to the load method. This is useful if you don't want to load all data, in those cases where you don't need all the data that the object can hold. 
+In this class it gets even more interesting, because you may pass a
+list of those to the load method. This is useful if you don't want to
+load all data, in those cases where you don't need all the data that
+the object can hold.
 
 These are the names of the stored data of this class:
 
 =over
 
-=item * storyname - an identifier for the story, a simple word you use to retrieve the desired object. 
+=item * storyname - an identifier for the story, a simple word you use
+to retrieve the desired object.
 
-=item * sectionid - an identifier for the section, also a simple word you use to retrieve the desired object. 
+=item * sectionid - an identifier for the section, also a simple word
+you use to retrieve the desired object.
 
-=item * image - the URL of an image that you want to associate with the story.
+=item * image - the URL of an image that you want to associate with
+the story.
 
-=item * primcat - the primary category. You want to classify the story into one primary category.
+=item * primcat - the primary category. You want to classify the story
+into one primary category.
 
-=item * seccat - the secondary categories. May be an array, so you can classify the story into any number of categories. This may be useful when you try to find relevant articles but searching along different paths. 
+=item * seccat - the secondary categories. May be an array, so you can
+classify the story into any number of categories. This may be useful
+when you try to find relevant articles but searching along different
+paths.
 
-=item * freesubject - free categories. The primary categories are intended to be controlled vocabularies, whereas free subjects can be used and created more ad hoc. Also an array, you can have any number of such categories.
+=item * freesubject - free categories. The primary categories are
+intended to be controlled vocabularies, whereas free subjects can be
+used and created more ad hoc. Also an array, you can have any number
+of such categories.
 
-=item * editorok - a boolean variable indicated if an editor has approved the story for publishing. 
+=item * editorok - a boolean variable indicated if an editor has
+approved the story for publishing.
 
 =item * title - the main title of the story. 
 
-=item * minicontent - Intended to be used as a summary or introduction to a story. Typically, the minicontent will be shown on a front page, where a visitor clicks happily along to read the full story. 
+=item * minicontent - Intended to be used as a summary or introduction
+to a story. Typically, the minicontent will be shown on a front page,
+where a visitor clicks happily along to read the full story.
 
 =item * content - the full story text.
 
-=item * username - the username of the user who actually does the posting of hte story. Would usually be an editor. 
+=item * username - the username of the user who actually does the
+posting of hte story. Would usually be an editor.
 
-=item * submitterid - the username of the user who submitted the article to the site for review and posting. 
+=item * submitterid - the username of the user who submitted the
+article to the site for review and posting.
 
-=item * linktext - "Read More" makes a bad link text. Link texts should be meaningful when read out of context, and this should contain such a text.
+=item * linktext - "Read More" makes a bad link text. Link texts
+should be meaningful when read out of context, and this should contain
+such a text.
 
-=item * timestamp - typically the time when the story was posted. See also the C<timestamp()> method.
+=item * timestamp - typically the time when the story was posted. See
+also the C<timestamp()> method.
 
-=item * lasttimestamp - typically the time when something attached to the story was last changed, for example when a comment was last submitted. See also the C<lasttimestamp()> method.
+=item * lasttimestamp - typically the time when something attached to
+the story was last changed, for example when a comment was last
+submitted. See also the C<lasttimestamp()> method.
 
 =back
 
@@ -314,7 +369,12 @@ that are
 
 =head1 BUGS/TODO
 
-Besides that it is in alpha, there is a quirk in the load method. I use SQL3 arrays in the underlying database, but the database driver doesn't support this. So, there is a very hackish ad hoc implementation to parse the arrays in that method. It is in fact the only reason why this class reimplements the load method. It works partly for reading, but just with  L<DBD::Pg> greater than 1.32.
+Besides that it is in alpha, there is a quirk in the load method. I
+use SQL3 arrays in the underlying database, but the database driver
+doesn't support this. So, there is a very hackish ad hoc
+implementation to parse the arrays in that method. It is in fact the
+only reason why this class reimplements the load method. It works
+partly for reading, but just with L<DBD::Pg> greater than 1.32.
 
 =head1 FORMALITIES
 
